pub struct SimulateQueryOptions {
pub estimate_gas_unit_price: bool,
pub estimate_max_gas_amount: bool,
pub estimate_prioritized_gas_unit_price: bool,
}Expand description
Query options for the fullnode /transactions/simulate endpoint.
These options are passed as query parameters to the simulate API.
When set to true, the node may override transaction gas fields or use
estimated values for simulation (see Aptos API docs).
Fields
estimate_gas_unit_price: boolWhen true, the gas unit price in the transaction may be ignored and the estimated gas unit price used instead.
estimate_max_gas_amount: boolWhen true, the max gas amount in the transaction may be ignored and the maximum possible gas used instead.
estimate_prioritized_gas_unit_price: boolWhen true, use a higher prioritized gas unit price for simulation.
Implementations
Sourceimpl SimulateQueryOptions
impl SimulateQueryOptions
Sourcepub fn estimate_gas_unit_price(self, value: bool) -> Self
pub fn estimate_gas_unit_price(self, value: bool) -> Self
Requests the node to estimate gas unit price for simulation.
Sourcepub fn estimate_max_gas_amount(self, value: bool) -> Self
pub fn estimate_max_gas_amount(self, value: bool) -> Self
Requests the node to estimate max gas amount for simulation.
Sourcepub fn estimate_prioritized_gas_unit_price(self, value: bool) -> Self
pub fn estimate_prioritized_gas_unit_price(self, value: bool) -> Self
Requests the node to use prioritized gas unit price for simulation.